@@ -10,9 +10,11 @@ use url::ParseError;
 
 /// Errors propagated by library functions.
 #[derive(Error, Debug)]
-pub enum ArweaveError {
+pub enum Error {
     #[error("base64 decode: {0}")]
     Base64Decode(#[from] DecodeError),
+    #[error("bincode: {0}")]
+    Bincode(#[from] Box<bincode::ErrorKind>),
     #[error("unhandled boxed dyn error {0}")]
     BoxedDynStd(#[from] Box<dyn std::error::Error>),
     #[error("formatting error")]
@@ -43,6 +45,8 @@ pub enum ArweaveError {
     SerdeJson(#[from] serde_json::Error),
     #[error("status not found")]
     StatusNotFound,
+    #[error("solana hash parse {0}")]
+    SolanaHashParse(#[from] solana_sdk::hash::ParseHashError),
     #[error("transaction is not signed")]
     UnsignedTransaction,
     #[error("url parse error: {0}")]
